party-admin-edit
================
Tryton module to allow edit of some fields on party.

Install
=======

pip install mds-party-admin-edit

Requires
========
- Tryton 4.6

Changes
=======

*4.6.0 - 14.01.2020*

- init
